summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libcvs/cvshandler.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /kbabel/catalogmanager/libcvs/cvshandler.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbabel/catalogmanager/libcvs/cvshandler.h')
-rw-r--r--kbabel/catalogmanager/libcvs/cvshandler.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/kbabel/catalogmanager/libcvs/cvshandler.h b/kbabel/catalogmanager/libcvs/cvshandler.h
index 961c41fd..78e248da 100644
--- a/kbabel/catalogmanager/libcvs/cvshandler.h
+++ b/kbabel/catalogmanager/libcvs/cvshandler.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -35,13 +35,13 @@
#ifndef CVSHANDLER_H
#define CVSHANDLER_H
// Qt include files
#include <tqmap.h>
#include <tqobject.h>
// Project specific include files
#include "cvsdialog.h"
#include "cvsresources.h"
// Forwarding Qt classes
class TQString;
class TQStringList;
class TQWidget;
@@ -54,12 +54,13 @@ class KSharedConfig;
* @short Backend for CVS support in Catalog Manager
* @author Marco Wegner <mail@marcowegner.de>
*/
-class CVSHandler : public QObject
+class CVSHandler : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- enum FileStatus {
+ enum FiletqStatus {
NO_REPOSITORY,
NOT_IN_CVS,
LOCALLY_ADDED,
@@ -69,24 +70,24 @@ class CVSHandler : public QObject
UP_TO_DATE
};
- CVSHandler( const TQString& poBaseDir = TQString::null, const TQString& potBaseDir = TQString::null );
+ CVSHandler( const TQString& poBaseDir = TQString(), const TQString& potBaseDir = TQString() );
void setPOBaseDir( const TQString& dir );
void setPOTBaseDir( const TQString& dir );
- FileStatus fstatus( const TQString& filename ) const;
- TQString fileStatus( const FileStatus status ) const;
- TQString cvsStatus( const TQString& filename ) const;
+ FiletqStatus fstatus( const TQString& filename ) const;
+ TQString filetqStatus( const FiletqStatus status ) const;
+ TQString cvstqStatus( const TQString& filename ) const;
- void execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQString& filename, bool templates, KSharedConfig* config );
- void execCVSCommand( TQWidget* parent, CVS::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config );
+ void execCVSCommand( TQWidget* tqparent, CVS::Command cmd, const TQString& filename, bool templates, KSharedConfig* config );
+ void execCVSCommand( TQWidget* tqparent, CVS::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config );
void setAutoUpdateTemplates( bool update );
/**
* True if the file was modified or has another status considered as a modification
*/
- bool isConsideredModified( const FileStatus status ) const;
+ bool isConsideredModified( const FiletqStatus status ) const;
signals:
void signalIsPORepository( bool );
@@ -94,7 +95,7 @@ class CVSHandler : public QObject
void signalFilesCommitted( const TQStringList& );
private:
- void showDialog( TQWidget* parent, CVS::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config );
+ void showDialog( TQWidget* tqparent, CVS::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config );
void checkToAdd( const TQStringList& files );
void processStatusOutput( const TQString& status );
void processDiff( TQString output );
@@ -35,13 +35,13 @@
#ifndef CVSHANDLER_H
#define CVSHANDLER_H
-// Qt include files
+// TQt include files
#include <tqmap.h>
#include <tqobject.h>
@@ -35,13 +35,13 @@
#include "cvsdialog.h"
#include "cvsresources.h"
-// Forwarding Qt classes
+// Forwarding TQt classes
class TQString;
class TQStringList;